@@ -3,11 +3,7 @@ import pandas as pd
 # import os
 
 from pneuro.appLogger import AppLogger
-import pathlib
-# The directory containing this file
-HERE = pathlib.Path(__file__).parent
-# The text of the README file
-dataLoadLogs = HERE/"logs"/"dataLoadLogs.txt"
+
 
 class DataGetter():
     """
