@@ -3,12 +3,6 @@ import os
 import shutil
 
 from pneuro.appLogger import AppLogger
-import pathlib
-
-# The directory containing this file
-HERE = pathlib.Path(__file__).parent
-# The text of the README file
-fileOperationLogs = HERE/"logs"/"fileOperationLogs.txt"
 
 
 class FileOperation:
