@@ -9,12 +9,7 @@ from sklearn.preprocessing import LabelEncoder
 from sklearn.preprocessing import MinMaxScaler
 
 from pneuro.appLogger import AppLogger
-import pathlib
 
-# The directory containing this file
-HERE = pathlib.Path(__file__).parent
-# The text of the README file
-dataPreprocessingLogs = HERE/"logs"/"dataPreprocessingLogs.txt"
 
 class Preprocessor():
     """
