@@ -7,12 +7,7 @@ import xgboost as xgb
 from sklearn.neighbors import KNeighborsRegressor
 from pneuro.appLogger import AppLogger
 from pneuro.file_methods import FileOperation
-import pathlib
 
-# The directory containing this file
-HERE = pathlib.Path(__file__).parent
-# The text of the README file
-RegressionTrainingLogs = HERE/"logs"/"RegressionTrainingLogs.txt"
 
 class RegressionModelTuner():
     """
